/* ----------------------------------------------------------------------
*  HGM Extended Help Documentation                                      *
*                                                                       *
* Copyright - 2021 - Stuart Aitken - www.harbour-guide.com              *
*                                                                       *
* Username at www.hmgforum.com - Zimbo                                  *
*                                                                       *
* ----------------------------------------------------------------------*/

#include "hmg.ch"

/* -------------------------------------------------------------------- */

/*  The MAIN Function hierarchy;
        DEFINE the MAIN Window
            DEFINE a SPLITBOX
                Create a LISTBOX within the SPLITBOX
                DEFINE a SPLITCHILD within the SPLITBOX
                    Create Controls within the SPLITCHILD
                END definition of the SPLITCHILD
            END definition of the SPLITBOX
        END definition of the MAIN Window
*/

FUNCTION Main()

DEFINE WINDOW           Win_Main        ;
    ROW                 10              ;
    COL                 10              ;
    WIDTH               500             ;
    HEIGHT              300             ;
    TITLE               "MAIN Window"   ;
    ICON                "HMG Guide.ico" ;
    WINDOWTYPE          MAIN            ;
    FONTNAME            "Arial"         ;
    FONTSIZE            8               ;
    BACKCOLOR           {255, 255, 240} ;
    ONINIT              nil             ;
    ONRELEASE           nil             ;
    ONINTERACTIVECLOSE  nil             ;
    
    DEFINE SPLITBOX
    
        // ROW and COL for Controls - are NOT used in a SPLITBOX
        DEFINE LISTBOX      Lst1
            WIDTH           100
            HEIGHT          150
            ITEMS           {"Choice 1", "Choice 2", "Choice 3", ;
                             "Choice 4", "Choice 5"}
            VALUE           5
            FONTNAME        "Arial"
            FONTSIZE        8
            ONCHANGE        UpdSpChild()
        END LISTBOX

        DEFINE WINDOW       Win_SpCh1               ; 
            WIDTH           400                     ;
            HEIGHT          150                     ;
            VIRTUALWIDTH    600                     ;
            VIRTUALHEIGHT   400                     ;
            TITLE           "SPLITCHILD Window"     ;
            WINDOWTYPE      SPLITCHILD              ;
            FONTNAME        "Arial"                 ;
            FONTSIZE        10                      ;
            TITLEBAR        .T.                     ;
            CURSOR          "finger.cur"            ;
            ;//GRIPPERTEXT     "<->"                   ;
            ;//BREAK           .F.                     ;    // Tested OK. Changes appearance and order to vertical. IGNORES any logical value (known issue)
            ;//FOCUSED         .F.                     ;    // Tested OK. Gives the Window Focus on init. IGNORES any logical value (known issue)
            ONPAINT         nil                     ;
            ONGOTFOCUS      nil                     ;
            ONLOSTFOCUS     nil                     ;
            ONSCROLLUP      nil                     ;
            ONSCROLLDOWN    nil                     ;
            ONSCROLLLEFT    nil                     ;
            ONSCROLLRIGHT   nil                     ;
            ONHSCROLLBOX    nil                     ;
            ONVSCROLLBOX    nil                     ;

            // ROW and COL for Controls ARE used inside a SPLITCHILD
            DEFINE LABEL        Lbl1
                PARENT          Win_SpCh1
                ROW	            10
                COL	            20
                VALUE           "A Static Label"
                AUTOSIZE        .T.
            END LABEL
            
            DEFINE FRAME        Frm1
                PARENT          Win_SpCh1
                ROW	            1
                COL	            115
                WIDTH           85
                HEIGHT          90
            END FRAME

            DEFINE RADIOGROUP   Rad1
                PARENT          Win_SpCh1
                ROW	            5
                COL	            125
                WIDTH           50
                OPTIONS         {"One", "Two", "Three"}
                VALUE           2
                ONCHANGE        UpdSpChild()
            END RADIOGROUP
            
            DEFINE CHECKBUTTON  ChkBtn1
                PARENT          Win_SpCh1
                ROW             5
                COL             210
                CAPTION         "Turn On"
                WIDTH           75
                HEIGHT          25
                VALUE           .F.
                ONCHANGE        UpdSpChild()
            END CHECKBUTTON
            
            DEFINE CHECKBOX     ChkBox1
                PARENT          Win_SpCh1
                ROW             50
                COL             210
                CAPTION         "Untick Me"
                VALUE           .T.
                WIDTH           100
                HEIGHT          28
                ONCHANGE        UpdSpChild()
            END CHECKBOX
            
        END WINDOW    // Win_SpCh1
    
    END SPLITBOX

    // The LISTBOX is an entity within the SPLITBOX container and is referenced accordingly.
    //     See code to change the VALUE below
    DEFINE LABEL    Lbl1
        PARENT      Win_Main
        ROW	        170
        COL	        20
        VALUE       "List Value: " + ALLTRIM(STR(Win_Main.SPLITBOX.Lst1.VALUE))
        AUTOSIZE    .T.
        TRANSPARENT .T.
    END LABEL

    // Whilst it is defined as an entity within the SPLITBOX. a SPLITCHILD Window must be referenced directly
    //     See code to change the VALUE below
    DEFINE LABEL    Lbl2
        PARENT      Win_Main
        ROW	        190
        COL	        20
        VALUE       "Radio Value: " + ALLTRIM(STR(Win_SpCh1.Rad1.VALUE))
        AUTOSIZE    .T.
        TRANSPARENT .T.
    END LABEL

    DEFINE LABEL    Lbl3
        PARENT      Win_Main
        ROW	        210
        COL	        20
        VALUE       "Check Button Value: " + IIF(Win_SpCh1.ChkBtn1.VALUE, "True", "False")
        AUTOSIZE    .T.
        TRANSPARENT .T.
    END LABEL

    DEFINE LABEL    Lbl4
        PARENT      Win_Main
        ROW	        230
        COL	        20
        VALUE       "Check Box Value: " + IIF(Win_SpCh1.ChkBox1.VALUE, "True", "False")
        AUTOSIZE    .T.
        TRANSPARENT .T.
    END LABEL
    
    DEFINE BUTTON   Btn1
        PARENT      Win_Main
        ROW         190
        COL         220
        WIDTH       75
        HEIGHT      25
        CAPTION     "Reset"
        ONCLICK     ResetVals() //TestIt() function can be used here for testing
    END BUTTON
    
END WINDOW    // Win_Main

ACTIVATE WINDOW Win_Main

RETURN nil

/* -------------------------------------------------------------------- */

FUNCTION UpdSpChild()

Win_Main.Lbl1.VALUE := "List Value: " + ALLTRIM(STR(Win_Main.SPLITBOX.Lst1.VALUE))

Win_Main.Lbl2.VALUE := "Radio Value: " + ALLTRIM(STR(Win_SpCh1.Rad1.VALUE))

IF Win_SpCh1.ChkBtn1.VALUE
        Win_Main.Lbl3.VALUE         := "Check Button Value: TRUE"
        Win_SpCh1.ChkBtn1.CAPTION   := "Turn Off"
    ELSE
        Win_Main.Lbl3.VALUE         := "Check Button Value: FALSE"
        Win_SpCh1.ChkBtn1.CAPTION   := "Turn On"
ENDIF

IF Win_SpCh1.ChkBox1.VALUE
        Win_Main.Lbl4.VALUE         := "Check Box Value: TRUE"
        Win_SpCh1.ChkBox1.CAPTION   := "Untick Me"
    ELSE
        Win_Main.Lbl4.VALUE         := "Check Box Value: FALSE"
        Win_SpCh1.ChkBox1.CAPTION   := "Tick Me"
ENDIF

RETURN nil

/* -------------------------------------------------------------------- */

FUNCTION ResetVals()

Win_Main.SPLITBOX.Lst1.VALUE := 1
Win_SpCh1.Rad1.VALUE         := 1
Win_SpCh1.ChkBtn1.VALUE      := .F.
Win_SpCh1.ChkBox1.VALUE      := .F.

RETURN nil

/* -------------------------------------------------------------------- */

FUNCTION TestIt()

STATIC lRunOnce := .T.

// Code to test the values used for the newer properties avaliable after
// the Window is activated. Refer to help documentation and / or use this
// code calling TestIt() from Win_Main.Btn1
/*
IF lRunOnce
        Win_SpCh1.NOCAPTION := .T.
        lRunOnce := .F.
    ELSE
        MsgInfo(Win_SpCh1.NOCAPTION)
ENDIF
*/
*
RETURN nil

/* -------------------------------------------------------------------- */